---
# https://vitepress.dev/reference/default-theme-home-page
layout: home

hero:
  name: "Django project base"
  text: ""
  tagline: This project removes the boilerplate associated with project and user handling.
  actions:
    - theme: brand
      text: Getting started
      link: /installation
    - theme: brand
      text: Manual
      link: /introduction
    - theme: alt
      text: View on Github
      link: https://github.com/velis74/django-project-base

features:
  - title: Removes the boilerplate
    details: This project removes the boilerplate associated with project and user handling.
  - title: We start with a project
    details: Everything revolves around it, users, roles, permissions, tags, etc.
  - title: Provides foundations
    details: For user profiles, oauth authentication, permissions, projects, tagging, etc.
---

